@@ -12,11 +12,13 @@ import random
 import shutil
 import threading
 import time
+from typing import Any, Dict, List, Type
 
 import yaml
 
 from galaxy.exceptions import ObjectInvalid, ObjectNotFound
 from galaxy.util import (
+    asbool,
     directory_hash_id,
     force_symlink,
     parse_xml,
@@ -213,6 +215,8 @@ class ObjectStore(metaclass=abc.ABCMeta):
 
 
 class BaseObjectStore(ObjectStore):
+    store_by: str
+    store_type: str
 
     def __init__(self, config, config_dict=None, **kwargs):
         """
@@ -772,6 +776,7 @@ class DistributedObjectStore(NestedObjectStore):
         self.original_weighted_backend_ids = []
         self.max_percent_full = {}
         self.global_max_percent_full = config_dict.get("global_max_percent_full", 0)
+        self.search_for_missing = config_dict.get("search_for_missing", True)
         random.seed()
 
         for backend_def in config_dict["backends"]:
@@ -795,8 +800,8 @@ class DistributedObjectStore(NestedObjectStore):
         self.sleeper = None
         if fsmon and (self.global_max_percent_full or [_ for _ in self.max_percent_full.values() if _ != 0.0]):
             self.sleeper = Sleeper()
-            self.filesystem_monitor_thread = threading.Thread(target=self.__filesystem_monitor)
-            self.filesystem_monitor_thread.setDaemon(True)
+            self.filesystem_monitor_thread = threading.Thread(target=self.__filesystem_monitor, args=[self.sleeper])
+            self.filesystem_monitor_thread.daemon = True
             self.filesystem_monitor_thread.start()
             log.info("Filesystem space monitor started")
 
@@ -807,8 +812,9 @@ class DistributedObjectStore(NestedObjectStore):
         else:
             backends_root = config_xml.find('backends')
 
-        backends = []
+        backends: List[Dict[str, Any]] = []
         config_dict = {
+            'search_for_missing': asbool(backends_root.get('search_for_missing', True)),
             'global_max_percent_full': float(backends_root.get('maxpctfull', 0)),
             'backends': backends,
         }
@@ -851,10 +857,11 @@ class DistributedObjectStore(NestedObjectStore):
         config_dict = clazz.parse_xml(config_xml, legacy=legacy)
         return clazz(config, config_dict, fsmon=fsmon)
 
-    def to_dict(self):
+    def to_dict(self) -> Dict[str, Any]:
         as_dict = super().to_dict()
         as_dict["global_max_percent_full"] = self.global_max_percent_full
-        backends = []
+        as_dict["search_for_missing"] = self.search_for_missing
+        backends: List[Dict[str, Any]] = []
         for backend_id, backend in self.backends.items():
             backend_as_dict = backend.to_dict()
             backend_as_dict["id"] = backend_id
@@ -870,7 +877,7 @@ class DistributedObjectStore(NestedObjectStore):
         if self.sleeper is not None:
             self.sleeper.wake()
 
-    def __filesystem_monitor(self):
+    def __filesystem_monitor(self, sleeper: Sleeper):
         while self.running:
             new_weighted_backend_ids = self.original_weighted_backend_ids
             for id, backend in self.backends.items():
@@ -879,7 +886,7 @@ class DistributedObjectStore(NestedObjectStore):
                 if pct > maxpct:
                     new_weighted_backend_ids = [_ for _ in new_weighted_backend_ids if _ != id]
             self.weighted_backend_ids = new_weighted_backend_ids
-            self.sleeper.sleep(120)  # Test free space every 2 minutes
+            sleeper.sleep(120)  # Test free space every 2 minutes
 
     def _create(self, obj, **kwargs):
         """The only method in which obj.object_store_id may be None."""
@@ -915,15 +922,15 @@ class DistributedObjectStore(NestedObjectStore):
             else:
                 log.warning('The backend object store ID (%s) for %s object with ID %s is invalid'
                             % (obj.object_store_id, obj.__class__.__name__, obj.id))
-        # if this instance has been switched from a non-distributed to a
-        # distributed object store, or if the object's store id is invalid,
-        # try to locate the object
-        for id, store in self.backends.items():
-            if store.exists(obj, **kwargs):
-                log.warning('%s object with ID %s found in backend object store with ID %s'
-                            % (obj.__class__.__name__, obj.id, id))
-                obj.object_store_id = id
-                return id
+        elif self.search_for_missing:
+            # if this instance has been switched from a non-distributed to a
+            # distributed object store, or if the object's store id is invalid,
+            # try to locate the object
+            for id, store in self.backends.items():
+                if store.exists(obj, **kwargs):
+                    log.warning(f"{obj.__class__.__name__} object with ID {obj.id} found in backend object store with ID {id}")
+                    obj.object_store_id = id
+                    return id
         return None
 
 
@@ -941,7 +948,7 @@ class HierarchicalObjectStore(NestedObjectStore):
         """The default constructor. Extends `NestedObjectStore`."""
         super().__init__(config, config_dict)
 
-        backends = {}
+        backends: Dict[int, ObjectStore] = {}
         for order, backend_def in enumerate(config_dict["backends"]):
             backends[order] = build_object_store_from_config(config, config_dict=backend_def, fsmon=fsmon)
 
@@ -981,7 +988,7 @@ class HierarchicalObjectStore(NestedObjectStore):
 
 
 def type_to_object_store_class(store, fsmon=False):
-    objectstore_class = None
+    objectstore_class: Type[ObjectStore]
     objectstore_constructor_kwds = {}
     if store == 'disk':
         objectstore_class = DiskObjectStore
@@ -1009,6 +1016,8 @@ def type_to_object_store_class(store, fsmon=False):
     elif store == 'pithos':
         from .pithos import PithosObjectStore
         objectstore_class = PithosObjectStore
+    else:
+        raise Exception(f"Unrecognized object store definition: {store}")
     # Disable the Pulsar object store for now until it receives some attention
     # elif store == 'pulsar':
     #    from .pulsar import PulsarObjectStore
@@ -1059,9 +1068,6 @@ def build_object_store_from_config(config, fsmon=False, config_xml=None, config_
         store = config_dict.get('type')
 
     objectstore_class, objectstore_constructor_kwds = type_to_object_store_class(store, fsmon=fsmon)
-    if objectstore_class is None:
-        log.error(f"Unrecognized object store definition: {store}")
-
     if from_object == 'xml':
         return objectstore_class.from_xml(config=config, config_xml=config_xml, **objectstore_constructor_kwds)
     else:
