@@ -57,7 +57,8 @@ class CloudConfigMixin:
             "cache": {
                 "size": self.cache_size,
                 "path": self.staging_path,
-            }
+            },
+            'enable_cache_monitor': False,
         }
 
 
@@ -76,6 +77,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
         bucket_dict = config_dict['bucket']
         connection_dict = config_dict.get('connection', {})
         cache_dict = config_dict['cache']
+        self.enable_cache_monitor = config_dict.get('enable_cache_monitor', True)
 
         self.provider = config_dict["provider"]
         self.credentials = config_dict["auth"]
@@ -100,8 +102,17 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
 
         self.conn = self._get_connection(self.provider, self.credentials)
         self.bucket = self._get_bucket(self.bucket_name)
+        self.start_cache_monitor()
+        # Test if 'axel' is available for parallel download and pull the key into cache
+        try:
+            subprocess.call('axel')
+            self.use_axel = True
+        except OSError:
+            self.use_axel = False
+
+    def start_cache_monitor(self):
         # Clean cache only if value is set in galaxy.ini
-        if self.cache_size != -1:
+        if self.cache_size != -1 and self.enable_cache_monitor:
             # Convert GBs to bytes for comparison
             self.cache_size = self.cache_size * 1073741824
             # Helper for interruptable sleep
@@ -109,12 +120,6 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             self.cache_monitor_thread = threading.Thread(target=self.__cache_monitor)
             self.cache_monitor_thread.start()
             log.info("Cache cleaner manager started")
-        # Test if 'axel' is available for parallel download and pull the key into cache
-        try:
-            subprocess.call('axel')
-            self.use_axel = True
-        except OSError:
-            self.use_axel = False
 
     @staticmethod
     def _get_connection(provider, credentials):
@@ -186,11 +191,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             missing_config = []
             if provider == "aws":
                 akey = auth_element.get("access_key")
-                if akey is None:
-                    missing_config.append("access_key")
                 skey = auth_element.get("secret_key")
-                if skey is None:
-                    missing_config.append("secret_key")
 
                 config["auth"] = {
                     "access_key": akey,
@@ -404,8 +405,6 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
         except Exception:
             log.exception("Trouble checking existence of S3 key '%s'", rel_path)
             return False
-        if rel_path[0] == '/':
-            raise
         return exists
 
     def _in_cache(self, rel_path):
@@ -418,7 +417,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
         # Ensure the cache directory structure exists (e.g., dataset_#_files/)
         rel_path_dir = os.path.dirname(rel_path)
         if not os.path.exists(self._get_cache_path(rel_path_dir)):
-            os.makedirs(self._get_cache_path(rel_path_dir))
+            os.makedirs(self._get_cache_path(rel_path_dir), exist_ok=True)
         # Now pull in the file
         file_ok = self._download(rel_path)
         self._fix_permissions(self._get_cache_path(rel_path_dir))
@@ -446,7 +445,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             else:
                 log.debug("Pulled key '%s' into cache to %s", rel_path, self._get_cache_path(rel_path))
                 self.transfer_progress = 0  # Reset transfer progress counter
-                with open(self._get_cache_path(rel_path), "w+") as downloaded_file_handle:
+                with open(self._get_cache_path(rel_path), "wb+") as downloaded_file_handle:
                     key.save_content(downloaded_file_handle)
                 return True
         except Exception:
@@ -530,7 +529,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             # for JOB_WORK directory
             elif base_dir:
                 if not os.path.exists(rel_path):
-                    os.makedirs(rel_path)
+                    os.makedirs(rel_path, exist_ok=True)
                 return True
             else:
                 return False
@@ -566,7 +565,7 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
             # Create given directory in cache
             cache_dir = os.path.join(self.staging_path, rel_path)
             if not os.path.exists(cache_dir):
-                os.makedirs(cache_dir)
+                os.makedirs(cache_dir, exist_ok=True)
 
             if not dir_only:
                 rel_path = os.path.join(rel_path, alt_name if alt_name else f"dataset_{self._get_object_id(obj)}.dat")
@@ -716,3 +715,11 @@ class Cloud(ConcreteObjectStore, CloudConfigMixin):
 
     def _get_store_usage_percent(self):
         return 0.0
+
+    def shutdown(self):
+        self.running = False
+        thread = getattr(self, 'cache_monitor_thread', None)
+        if thread:
+            log.debug("Shutting down thread")
+            self.sleeper.wake()
+            thread.join(5)
