@@ -5,7 +5,6 @@ import logging
 import os
 import shutil
 from datetime import datetime
-from functools import partial
 from pathlib import Path
 
 try:
@@ -31,6 +30,7 @@ IRODS_IMPORT_MESSAGE = ('The Python irods package is required to use this featur
 # 1 MB
 CHUNK_SIZE = 2**20
 log = logging.getLogger(__name__)
+logging.getLogger("irods.connection").setLevel(logging.INFO)  # irods logging generates gigabytes of logs
 
 
 def _config_xml_error(tag):
@@ -296,9 +296,10 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
 
         collection_path = f"{self.home}/{str(subcollection_name)}"
         data_object_path = f"{collection_path}/{str(data_object_name)}"
+        options = {kw.DEST_RESC_NAME_KW: self.resource}
 
         try:
-            data_obj = self.session.data_objects.get(data_object_path)
+            data_obj = self.session.data_objects.get(data_object_path, **options)
             return data_obj.__sizeof__()
         except (DataObjectDoesNotExist, CollectionDoesNotExist):
             log.warning("Collection or data object (%s) does not exist", data_object_path)
@@ -315,9 +316,10 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
 
         collection_path = f"{self.home}/{str(subcollection_name)}"
         data_object_path = f"{collection_path}/{str(data_object_name)}"
+        options = {kw.DEST_RESC_NAME_KW: self.resource}
 
         try:
-            self.session.data_objects.get(data_object_path)
+            self.session.data_objects.get(data_object_path, **options)
             return True
         except (DataObjectDoesNotExist, CollectionDoesNotExist):
             log.debug("Collection or data object (%s) does not exist", data_object_path)
@@ -335,7 +337,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         # Ensure the cache directory structure exists (e.g., dataset_#_files/)
         rel_path_dir = os.path.dirname(rel_path)
         if not os.path.exists(self._get_cache_path(rel_path_dir)):
-            os.makedirs(self._get_cache_path(rel_path_dir))
+            os.makedirs(self._get_cache_path(rel_path_dir), exist_ok=True)
         # Now pull in the file
         file_ok = self._download(rel_path)
         self._fix_permissions(self._get_cache_path(rel_path_dir))
@@ -352,30 +354,19 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
 
         collection_path = f"{self.home}/{str(subcollection_name)}"
         data_object_path = f"{collection_path}/{str(data_object_name)}"
-        data_obj = None
+        options = {kw.DEST_RESC_NAME_KW: self.resource}
 
         try:
-            data_obj = self.session.data_objects.get(data_object_path)
+            cache_path = self._get_cache_path(rel_path)
+            self.session.data_objects.get(data_object_path, cache_path, **options)
+            log.debug("Pulled data object '%s' into cache to %s", rel_path, cache_path)
+            return True
         except (DataObjectDoesNotExist, CollectionDoesNotExist):
             log.warning("Collection or data object (%s) does not exist", data_object_path)
             return False
         finally:
             log.debug("irods_pt _download: %s", ipt_timer)
 
-        if self.cache_size > 0 and data_obj.__sizeof__() > self.cache_size:
-            log.critical("File %s is larger (%s) than the cache size (%s). Cannot download.",
-                        rel_path, data_obj.__sizeof__(), self.cache_size)
-            log.debug("irods_pt _download: %s", ipt_timer)
-            return False
-
-        log.debug("Pulled data object '%s' into cache to %s", rel_path, self._get_cache_path(rel_path))
-
-        with data_obj.open('r') as data_obj_fp, open(self._get_cache_path(rel_path), "wb") as cache_fp:
-            for chunk in iter(partial(data_obj_fp.read, CHUNK_SIZE), b''):
-                cache_fp.write(chunk)
-        log.debug("irods_pt _download: %s", ipt_timer)
-        return True
-
     def _push_to_irods(self, rel_path, source_file=None, from_string=None):
         """
         Push the file pointed to by ``rel_path`` to the iRODS. Extract folder name
@@ -391,7 +382,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         subcollection_name = p.parent
 
         source_file = source_file if source_file else self._get_cache_path(rel_path)
-        options = {kw.FORCE_FLAG_KW: ''}
+        options = {kw.FORCE_FLAG_KW: '', kw.DEST_RESC_NAME_KW: self.resource}
 
         if not os.path.exists(source_file):
             log.error("Tried updating key '%s' from source file '%s', but source file does not exist.", rel_path, source_file)
@@ -401,6 +392,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         collection_path = f"{self.home}/{str(subcollection_name)}"
         data_object_path = f"{collection_path}/{str(data_object_name)}"
         exists = False
+
         try:
             exists = self.session.data_objects.exists(data_object_path)
 
@@ -409,12 +401,12 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
                 return True
 
             # Create sub-collection first
-            self.session.collections.create(collection_path, recurse=True)
-
-            # Create data object
-            data_obj = self.session.data_objects.create(data_object_path, self.resource, **options)
+            self.session.collections.create(collection_path, recurse=True, **options)
 
             if from_string:
+                # Create data object
+                data_obj = self.session.data_objects.create(data_object_path, self.resource, **options)
+
                 # Save 'from_string' as a file
                 with data_obj.open('w') as data_obj_fp:
                     data_obj_fp.write(from_string)
@@ -429,7 +421,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
                 log.debug("Pushing cache file '%s' of size %s bytes to collection '%s'", source_file, os.path.getsize(source_file), rel_path)
 
                 # Add the source file to the irods collection
-                self.session.data_objects.put(source_file, f"{collection_path}/", **options)
+                self.session.data_objects.put(source_file, data_object_path, **options)
 
                 end_time = datetime.now()
                 log.debug("Pushed cache file '%s' to collection '%s' (%s bytes transfered in %s sec)",
@@ -470,7 +462,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         if dir_only and base_dir:
             # for JOB_WORK directory
             if not os.path.exists(rel_path):
-                os.makedirs(rel_path)
+                os.makedirs(rel_path, exist_ok=True)
             log.debug("irods_pt _exists: %s", ipt_timer)
             return True
         log.debug("irods_pt _exists: %s", ipt_timer)
@@ -498,7 +490,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
             # Create given directory in cache
             cache_dir = os.path.join(self.staging_path, rel_path)
             if not os.path.exists(cache_dir):
-                os.makedirs(cache_dir)
+                os.makedirs(cache_dir, exist_ok=True)
 
             if not dir_only:
                 rel_path = os.path.join(rel_path, alt_name if alt_name else f"dataset_{self._get_object_id(obj)}.dat")
@@ -538,6 +530,8 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
         dir_only = kwargs.get('dir_only', False)
         obj_dir = kwargs.get('obj_dir', False)
 
+        options = {kw.DEST_RESC_NAME_KW: self.resource}
+
         try:
             # Remove temparory data in JOB_WORK directory
             if base_dir and dir_only and obj_dir:
@@ -583,7 +577,7 @@ class IRODSObjectStore(DiskObjectStore, CloudConfigMixin):
                 data_object_path = f"{collection_path}/{str(data_object_name)}"
 
                 try:
-                    data_obj = self.session.data_objects.get(data_object_path)
+                    data_obj = self.session.data_objects.get(data_object_path, **options)
                     # remove object
                     data_obj.unlink(force=True)
                     return True
